@@ -30,10 +30,12 @@ try:
     from Toolkit.analyse import AnalyseManager
     from Toolkit.localRE import TaiwanAddressAnalizer
     from Toolkit.toolkits import *
+    from Toolkit.NER import GenericNER
 except: #供外部載入時使用。
     from .Toolkit.analyse import AnalyseManager
     from .Toolkit.localRE import TaiwanAddressAnalizer
     from .Toolkit.toolkits import *
+    from .Toolkit.NER import GenericNER
 
 
 class MP_Articut:
@@ -72,6 +74,7 @@ class MP_Articut:
         # Toolkit
         self.analyse = AnalyseManager()
         self.localRE = TaiwanAddressAnalizer(locale="TW")
+        self.NER = GenericNER()
 
     def __str__(self):
         return "Articut Multiprocessing API"
